==> imgseries-0.8.0-py3-none-any.whl: imgseries/series/image_series.py <==
"""Class ImgSeries for image series manipulation"""

# Standard library imports
from functools import lru_cache

# Nonstandard
import filo

# local imports
from ..config import CONFIG
from ..readers import SingleImageReader
from ..viewers import ImgSeriesViewer

from .image_base import ImgSeriesBase


class ImgSeries(ImgSeriesBase, filo.Series):
    """Class to manage series of images, possibly in several folders."""

    # Only for __repr__ (str representation of class object, see filo.Series)
    name = 'Image Series'

    # Default filename to save file info with save_info (see filo.Series)
    info_filename = CONFIG['filenames']['files'] + '.tsv'

    # To distinguish between ImgSeries and ImgStack
    is_stack = False

    def __init__(
        self,
        paths='.',
        extension='.png',
        savepath='.',
        corrections=None,
        transforms=None,
        ImgViewer=ImgSeriesViewer,
        ImgReader=SingleImageReader,
    ):
        """Init image series object.

        Parameters
        ----------
        paths : str, path object or iterable of those
            can be a string, path object, or a list of str/paths if data
            is stored in multiple folders.

        extension : str
            extension of files to consider (e.g. '.png')

        savepath: str or path object
            folder in which to save parameters (transform, display etc.)

        corrections : iterable of str
            iterable of names of corrections to consider
            (their order indicates the order in which they are applied),
            e.g. corrections=('flicker', 'shaking');
            if None, use default order.

        transforms : iterable of str
            iterable of names of transforms to consider
            (their order indicates the order in which they are applied),
            e.g. transforms=('rotation', 'crop', 'filter');
            if None, use default order.

        ImgViewer : subclass of ImageViewerBase
            which Viewer class to use for show(), inspect() etc.
            if None, use default viewer class

        ImgReader : subclass of ImageReaderBase
            class (or object) that defines how to read images
        """
        # Inherit useful methods and attributes for file series
        # (including self.savepath)
        filo.Series.__init__(
            self,
            paths=paths,
            extension=extension,
            savepath=savepath,
        )

        ImgSeriesBase.__init__(
            self,
            corrections=corrections,
            transforms=transforms,
            ImgViewer=ImgViewer,
            ImgReader=ImgReader,
        )

        self._get_initial_image_dims()

    @property
    def nums(self):
        """Iterator (sliceable) of image identifiers.

        Examples
        --------
        Allows the user to do e.g.
        >>> for num in images.nums[::3]:
        >>>     images.read(num)
        """
        return range(len(self.files))


# ----------------------------------------------------------------------------
# ============== Factory function to generate ImgSeries objects ==============
# ----------------------------------------------------------------------------


def series(*args, cache=False, cache_size=516, **kwargs):
    """Generator of ImgSeries object with a caching option.

    Parameters
    ----------
    cache : bool
        If True, use caching to keep images in memory once loaded.

    cache_size : int
        Maximum number of images kept in memory by the cache if used.

    *args
    **kwargs
        Any arrguments and keyword arguments accepted by ImgSeries.
    """
    if not cache:

        return ImgSeries(*args, **kwargs)

    else:

        class ImgSeriesCached(ImgSeries):

            cache = True

            @lru_cache(maxsize=cache_size)
            def read(self, num=0, transform=True, **kwargs):
                return super().read(num, transform=transform, **kwargs)

        return ImgSeriesCached(*args, **kwargs)

==> imgseries-0.10.0-py3-none-any.whl: imgseries/series/image_series.py <==
"""Class ImgSeries for image series manipulation"""

# Nonstandard
import filo

# local imports
from ..config import CONFIG
from ..readers import SingleImageReader
from ..viewers import ImgSeriesViewer

from .image_base import ImgSeriesBase


class ImgSeries(ImgSeriesBase):
    """Class to manage series of images, possibly in several folders."""

    # Default filename to save file info with save_info (see filo.Series)
    info_filename = CONFIG['filenames']['files'] + '.tsv'

    # To distinguish between ImgSeries and ImgStack
    is_stack = False

    def __init__(
        self,
        folders='.',
        extension='.png',
        savepath='.',
        corrections=None,
        transforms=None,
        cache=False,
        Viewer=ImgSeriesViewer,
        Reader=SingleImageReader,
    ):
        """Init image series object.

        Parameters
        ----------
        paths : str, path object or iterable of those
            can be a string, path object, or a list of str/paths if data
            is stored in multiple folders.

        extension : str
            extension of files to consider (e.g. '.png')

        savepath: str or path object
            folder in which to save parameters (transform, display etc.)

        corrections : iterable of str
            iterable of names of corrections to consider
            (their order indicates the order in which they are applied),
            e.g. corrections=('flicker', 'shaking');
            if None, use default order.

        transforms : iterable of str
            iterable of names of transforms to consider
            (their order indicates the order in which they are applied),
            e.g. transforms=('rotation', 'crop', 'filter');
            if None, use default order.

        cache : bool
            if True, use caching for speed improvement
            (both for loading files and transforms)
            this is useful when calling read() multiple times on the same
            image (e.g. when inspecting series/stacks)

        Viewer : subclass of ImageViewerBase
            which Viewer class to use for show(), inspect() etc.
            if None, use default viewer class

        Reader : subclass of ImageReaderBase
            class (or object) that defines how to read images
        """
        self.files = filo.FileSeries.auto(
            folders=folders,
            extension=extension,
            refpath=savepath,
        )

        super().__init__(
            savepath=savepath,
            corrections=corrections,
            transforms=transforms,
            cache=cache,
            Viewer=Viewer,
            Reader=Reader,
        )

        self._get_initial_image_dims()

    def __repr__(self):
        return f"{super().__repr__()}\nfrom {self.files}"

    @property
    def info(self):
        return self.files.info

    def _get_info_filepath(self, filename):
        filename = CONFIG['filenames']['files'] if filename is None else filename
        return self.savepath / filename

    def load_times(self, filename=None):
        self.files.update_times(
            filepath=self._get_info_filepath(filename),
            sep=CONFIG['csv separator'],
        )

    def save_info(self, filename=None):
        self.files.to_csv(
            filepath=self._get_info_filepath(filename),
            sep=CONFIG['csv separator'],
        )

    @property
    def nums(self):
        """Iterator (sliceable) of image identifiers.

        Examples
        --------
        Allows the user to do e.g.
        >>> for num in images.nums[::3]:
        >>>     images.read(num)
        """
        return range(self.ntot)

    @property
    def ntot(self):
        """Total number of image files in the series.

        Returns
        -------
        int
        """
        return len(list(self.files))
